@@ -1,3 +1,4 @@
+/* vim: set sw=4 ts=4 et: */
 /*
  * Copyright (C) 2006, 2007 John Costigan.
  *
@@ -32,14 +33,16 @@
 #undef DEBUGFUNCTIONCALL
 #endif
 /*******************************************************************************/
+#ifdef ENABLE_GPS
 #ifdef OS2008
 
 #define PI   (3.14159265358979323846)
 #define EARTH_RADIUS (3443.91847)
-#define deg2rad(deg) ((deg) * (PI / 180.0)) 
-/*******************************************************************************/ 
+#define deg2rad(deg) ((deg) * (PI / 180.0))
+/*******************************************************************************/
 gdouble
-calculate_distance(gdouble lat1, gdouble lon1, gdouble lat2, gdouble lon2){
+calculate_distance(gdouble lat1, gdouble lon1, gdouble lat2,
+                   gdouble lon2) {
     gdouble dlat, dlon, slat, slon, a;
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
@@ -58,5 +61,7 @@ calculate_distance(gdouble lat1, gdouble lon1, gdouble lat2, gdouble lon2){
     a = (slat * slat) + (cos(lat1) * cos(lat2) * slon * slon);
     return ((2.0F * atan2(sqrt(a), sqrt(1.0F - a))) * EARTH_RADIUS);
 }
+
 /*******************************************************************************/
 #endif
+#endif
