@@ -1,3 +1,4 @@
+/* vim: set sw=4 ts=4 et: */
 /*
  * Copyright (C) 2006, 2007 John Costigan.
  *
@@ -27,9 +28,11 @@
 #include "weather-common.h"
 #include <math.h>
 /*******************************************************************************/
+#ifdef ENABLE_GPS
 #ifdef OS2008
 gdouble
 calculate_distance(gdouble lat1, gdouble lon1, gdouble lat2, gdouble lon2);
 #endif
+#endif
 /*******************************************************************************/
 #endif
