@@ -1,3 +1,4 @@
+/* vim: set sw=4 ts=4 et: */
 /*
  * This file is part of Other Maemo Weather(omweather)
  *
@@ -30,7 +31,11 @@
 /*******************************************************************************/
 #include "weather-common.h"
 #include <libosso.h>
-#ifdef OS2008
+#ifdef OS2009
+    #include <hildon/hildon-help.h>
+#elif OS2008
+    #include <hildon/hildon-help.h>
+#elif NONMAEMO
     #include <hildon/hildon-help.h>
 #else
     #include <osso-helplib.h>
