@@ -1,3 +1,4 @@
+/* vim: set sw=4 ts=4 et: */
 /*
  * This file is part of Other Maemo Weather(omweather)
  *
@@ -71,6 +72,10 @@ gboolean expose_main_window1(GtkWidget *widget, GdkEventExpose *event);
 GtkWidget*
 settings_menu(HildonDesktopHomeItem *home_item, GtkWindow *parent);
 #endif
+#ifdef OS2009
+gboolean
+omweather_init_OS2009(GtkWidget *applet);
+#endif
 /*******************************************************************************/
 extern void swap_temperature(int *hi, int *low);
 extern float c2f(float temp);
@@ -84,39 +89,54 @@ extern void add_periodic_event(time_t last_update);
 extern time_t calculate_diff_time(int timezone);
 extern void remove_daytime_event(void);
 extern void clean_download(void);
-extern void weather_window_settings(GtkWidget *widget, gpointer user_data);
 extern int read_config(AppletConfig*);
+extern void weather_window_settings(GtkWidget *widget, gpointer user_data);
 extern void config_save(AppletConfig*);
 extern GtkListStore* create_items_list(const char *path, const char *filename,
 				long start, long end, long *items_number);
 extern GtkListStore* create_time_update_list(void);
 extern gboolean show_popup_window_handler(GtkWidget *widget, GdkEvent *event,
 				    gpointer user_data);
-extern gint parse_weather_file_data(const gchar *station_id, WeatherStationData *wsd);
+extern gint parse_weather_file_data(const gchar *station_id, gchar *station_source,
+					WeatherStationData *wsd,
+						gboolean selected_detail_weather);
 extern gint parse_weather_com_xml(const gchar *station_id, weather_com_parser *parser,
 								WeatherStationData *wsd);
-extern gint parse_rp5_ru_xml(const gchar *station_id, weather_com_parser *parser,
+extern gint parse_weather_com_xml_hour(const gchar *station_id, weather_com_parser *parser,
 								WeatherStationData *wsd);
+extern gint parse_rp5_ru_xml(const gchar *station_id, weather_com_parser *parser, WeatherStationData *wsd);
 extern time_t last_update_time(GSList *object);
 extern float convert_wind_units(int to, float value);
-#ifdef OS2008
+#if defined(OS2008) || defined(OS2009)
 extern void initial_gps_connect(void);
 extern void deinitial_gps_connect(void);
+extern gboolean expose_parent(GtkWidget *widget, GdkEventExpose *event);
 #endif
 extern void weather_window_popup(GtkWidget *widget, GdkEvent *event, gpointer user_data);
 extern float mb2inch(float pressure);
-extern float mb2mm(float pressure);
-extern gboolean expose_parent(GtkWidget *widget, GdkEventExpose *event);
-#if defined(OS2008) || defined(DEBUGTEMP)
+#if defined(OS2008) || defined(DEBUGTEMP) || defined(OS2009)
 extern void read_sensor(gint need_redraw);
 extern WDB* create_sensor_icon_widget(const int icon_size, gboolean transparency,
 				gboolean draw_day_label, GdkColor *color);
 #endif
+#if defined (OS2009) || defined(NONMAEMO) || defined (APPLICATION)
+gboolean omweather_init_OS2009(GtkWidget *applet);
+void omweather_destroy(GtkObject *widget);
+#ifdef CLUTTER
+gboolean top_widget_expose(GtkWidget *widget, GdkEventExpose *event);
+#endif
+extern GtkWidget* create_time_updates_widget(GSList *current, gboolean change_color);
+#endif
+extern GtkWidget* create_toolbar_box(gpointer exit_function, gpointer arg_exit_function);
 extern void free_list_time_event(void);
 extern void event_add(time_t time_value, short int type_event);
 extern void destroy_popup_window(void);
-/*******************************************************************************/
-extern gchar	path_large_icon[];
+extern float mb2mm(float pressure);
+extern GtkWidget *create_icon_widget(GdkPixbuf *icon_buffer, const char *icon_path, int icon_size, GSList **objects_list);
+#ifdef CLUTTER
+void free_clutter_objects_list(GSList **clutter_objects);
+#endif
+extern gboolean show_animation(GSList *clutter_objects);
 /*******************************************************************************/
 typedef struct _HomeAppletHandler HomeAppletHandler;
 /*******************************************************************************/
@@ -137,4 +157,10 @@ struct _HomeAppletHandler {
 /*******************************************************************************/
 GtkWidget* hildon_home_applet_lib_settings(void *applet_data, GtkWindow *parent);
 /*******************************************************************************/
+#ifdef OS2009
+static void omweather_home_plugin_class_init (OmweatherHomePluginClass * klass);
+static void omweather_home_plugin_class_finalize (OmweatherHomePluginClass * klass);
+static void omweather_home_plugin_init (OmweatherHomePlugin * home_plugin);
+#endif 
+/*******************************************************************************/
 #endif
