@@ -1,8 +1,10 @@
+/* vim: set sw=4 ts=4 et: */
 /*
  * This file is part of Other Maemo Weather(omweather)
  *
  * Copyright (C) 2006 Vlad Vasiliev
  * Copyright (C) 2006 Pavel Fialko
+ * Copyright (C) 2008 Andrew Olmsted
  * 	for the code
  *        
  * Copyright (C) 2008 Andrew Zhilin
@@ -29,50 +31,63 @@
 #define _weather_settings_h 1
 /*******************************************************************************/
 #include "weather-common.h"
-#ifdef OS2008
+#ifdef OS2009
+    #include <hildon/hildon-controlbar.h>
+#elif OS2008
+    #include <hildon/hildon-controlbar.h>
+#elif NONMAEMO
     #include <hildon/hildon-controlbar.h>
 #else
     #include <hildon-widgets/hildon-controlbar.h>
 #endif
 /*******************************************************************************/
-#define OMWEATHER_RESPONSE_ABOUT 5000
-/*******************************************************************************/
 struct lists_struct{
-    GtkWidget	*countries;
-    GtkWidget	*states;
-    GtkWidget	*stations;
+    GtkWidget		*countries;
+    GtkListStore	*countries_list;
+    GtkWidget		*states;
+    GtkListStore	*regions_list;
+    GtkWidget		*stations;
+    GtkListStore	*stations_list;
+    GtkListStore	*sources_list;
+    sqlite3		*database;
+    gboolean		database_invalid;
 };
 /*******************************************************************************/
 extern gboolean		not_event;
-extern gchar		path_large_icon[_POSIX_PATH_MAX];
 extern WeatherSource	weather_sources[];
 /*******************************************************************************/
 void weather_window_settings(GtkWidget *widget, gpointer user_data);
 void station_list_view_select_handler(GtkTreeView *tree_view,
 			    gpointer user_data);
 gboolean process_locations_tab(GtkWidget *vbox);
-gboolean changed_country_process(gpointer user_data);
+gboolean process_visuals_tab(GtkWidget *vbox);
+gboolean process_display_tab(GtkWidget *vbox);
+gboolean process_units_tab(GtkWidget *vbox);
+gboolean process_update_tab(GtkWidget *vbox);
+#ifdef OS2008
+gboolean process_sensor_tab(GtkWidget *vbox);
+#endif
+gboolean process_alert_tab(GtkWidget *vbox);
 void changed_country_handler(GtkWidget *widget, gpointer user_data);
-gboolean changed_state_process(gpointer user_data);
 void changed_state_handler(GtkWidget *widget, gpointer user_data);
 void changed_stations_handler(GtkWidget *widget, gpointer user_data);
-void changed_weather_source_handler(GtkWidget *widget, gpointer user_data);
+void changed_sources_handler(GtkWidget *widget, gpointer user_data);
 void weather_window_add_custom_station(void);
-int create_icon_set_list(GSList **store); /* scan /usr/share/omweather/icons */
-					     /* and add names to the list */
 int get_active_item_index(GtkTreeModel *list, int time, const gchar *text,
 					    gboolean use_index_as_result);
 void update_iterval_changed_handler(GtkComboBox *widget, gpointer user_data);
 void transparency_button_toggled_handler(GtkToggleButton *togglebutton,
                                             gpointer user_data);
-gboolean check_station_code(const gint source, const gchar *station_code);
+gboolean check_station_code(gchar *source, const gchar *station_code);
 void up_key_handler(GtkButton *button, gpointer list);
 void down_key_handler(GtkButton *button, gpointer list);
+void new_station_handler(GtkButton *button, gpointer user_data);
 void delete_station_handler(GtkButton *button, gpointer user_data);
 void add_station_to_user_list(gchar *weather_station_id,gchar *weather_station_name,
-				gboolean is_gps, guint source);
+				gboolean is_gps, gchar *source);
 void highlight_current_station(GtkTreeView *tree_view);
 int lookup_and_select_station(gchar *db_path, gchar *station_name, Station *result);
+gboolean switch_cb(GtkNotebook * nb, gpointer nb_page, gint page, gpointer data);
 /*******************************************************************************/
 void apply_button_handler(GtkWidget *button, GdkEventButton *event,
 							    gpointer user_data);
@@ -84,8 +99,7 @@ void close_button_handler(GtkWidget *button, GdkEventButton *event,
 							    gpointer user_data);
 void back_button_handler(GtkWidget *button, GdkEventButton *event,
 							    gpointer user_data);
-void add_button_handler(GtkWidget *button, GdkEventButton *event,
-							    gpointer user_data);
+void add_button_handler(GtkWidget *button, gpointer user_data);
 void chk_download_button_toggled_handler(GtkRadioButton *button,
 							    gpointer user_data);
 void entry_changed_handler(GtkWidget *entry, gpointer user_data);
@@ -100,13 +114,6 @@ GtkWidget* create_units_tab(GtkWidget *window);
 GtkWidget* create_update_tab(GtkWidget *window);
 GtkWidget* create_test_tab(GtkWidget *window);
 void font_changed_handler(GtkFontButton *widget, gpointer user_data);
-gboolean process_visuals_tab(GtkWidget *vbox);
-gboolean process_display_tab(GtkWidget *vbox);
-gboolean process_units_tab(GtkWidget *vbox);
-gboolean process_update_tab(GtkWidget *vbox);
-#ifdef OS2008
-gboolean process_sensor_tab(GtkWidget *vbox);
-#endif
 /*******************************************************************************/
 extern void redraw_home_window(gboolean first_start);
 extern void remove_periodic_event(void);
@@ -126,7 +133,7 @@ extern void update_weather(gboolean show_update_window);
 extern GtkWidget* lookup_widget(GtkWidget *widget, const gchar *widget_name);
 extern void weather_window_popup(GtkWidget *widget, GdkEvent *event, gpointer user_data);
 extern GtkWidget* create_tree_view(GtkListStore* list);
-#if defined(OS2008) || defined(DEBUGTEMP)
+#if defined(OS2008) || defined(DEBUGTEMP) || defined(OS2009) || defined(NONMAEMO)
 extern GtkWidget* create_sensor_page(GtkWidget *config_window);
 extern void read_sensor(gint need_redraw);
 extern guint get_time_from_index(guint index);
@@ -136,5 +143,6 @@ extern GtkWidget* create_button_with_image(const char *path, const char *image_n
 extern GtkWidget* create_scrolled_window_with_text(const char* text,
 					    GtkJustification justification);
 extern guint get_index_from_time(guint time);
+extern void update_icons_set_base(const char *icon_set_name);
 /*******************************************************************************/
 #endif
