@@ -1,8 +1,10 @@
+/* vim: set sw=4 ts=4 et: */
 /*
  * This file is part of Other Maemo Weather(omweather)
  *
  * Copyright (C) 2006 Vlad Vasiliev
  * Copyright (C) 2006 Pavel Fialko
+ * Copyright (C) 2008 Andrew Olmsted
  * 	for the code
  *        
  * Copyright (C) 2008 Andrew Zhilin
@@ -34,6 +36,9 @@ float convert_wind_units(int to, float value);
 float mb2inch(float pressure);
 float mb2mm(float pressure);
 void set_font(GtkWidget *widget, const gchar *description, const gint size);
+gboolean draw_label_gradient(GtkWidget *widget, GdkEventExpose *event);
+gboolean draw_top_gradient(GtkWidget *widget, GdkEventExpose *event);
+gboolean draw_bottom_gradient(GtkWidget *widget, GdkEventExpose *event);
 void set_background_color(GtkWidget *widget, GdkColor *bgc);
 void set_font_color(GtkWidget *widget, guint16 red, guint16 green, guint16 blue);
 float c2f(float temp);
@@ -45,11 +50,17 @@ GtkWidget* lookup_widget(GtkWidget* widget, const gchar* widget_name);
 
 #define GLADE_HOOKUP_OBJECT_NO_REF(component,widget,name) \
     g_object_set_data (G_OBJECT (component), name, widget)
+GtkWidget* create_tool_item(const char *path, const char *image_name, int image_size);
 GtkWidget* create_button_with_image(const char *path, const char *image_name,
 				    int image_size, gboolean with_border,
 				    gboolean toggled);
 GtkWidget* create_tree_view(GtkListStore* list);
 GtkWidget* create_scrolled_window_with_text(const char* text,
 					    GtkJustification justification);
+int create_icon_set_list(gchar *dir_path, GSList **store, gchar *type); /* scan dir */
+					     /* and add names to the list */
+void update_icons_set_base(const char *icon_set_name);
+GtkWidget *create_icon_widget(GdkPixbuf *icon_buffer, const char *icon_path, int icon_size, GSList **objects_list);
+extern GtkWidget *create_clutter_main_icon(GdkPixbuf *icon_buffer, const char *icon_path, int icon_size, GSList **objects_list);
 /*******************************************************************************/
 #endif
